@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -176,12 +176,12 @@ public class CalDAVOnboardingProvider implements OnboardingPlistProvider {
                 CustomLoginSource customLoginSource = getHighestRankedCustomLoginSource();
                 if (null == customLoginSource) {
                     LOG.warn("Unable to find any CustomLoginSource services! Falling back to login name.");
-                    login = session.getLogin();
+                    login = OnboardingUtility.getUserLogin(session.getUserId(), session.getContextId());
                 } else {
                     login = customLoginSource.getCalDAVLogin(session.getUserId(), session.getContextId());
                 }
             } else {
-                login = session.getLogin();
+                login = OnboardingUtility.getUserLogin(session.getUserId(), session.getContextId());
             }
         }
         configuration.put(CALDAV_LOGIN_FIELD, login);
@@ -264,7 +264,7 @@ public class CalDAVOnboardingProvider implements OnboardingPlistProvider {
         ConfigView view = viewFactory.getView(userId, contextId);
         String propertyName = "com.openexchange.client.onboarding.caldav.url";
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             if (generateIfAbsent) {
                 return OnboardingUtility.constructURLWithParameters(hostData, null, "/caldav", null).toString();
             }
