@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -67,7 +67,6 @@ import com.openexchange.session.Sessions;
 import com.openexchange.session.UserAndContext;
 import com.openexchange.sessiond.SessionMatcher;
 import com.openexchange.sessiond.SessiondService;
-import com.openexchange.tools.session.ServerSession;
 import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 
@@ -473,14 +472,6 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
         return UserSettingMailStorage.getInstance().getUserSettingMail(userId, contextId);
     }
 
-    private User getUser(Session session) throws OXException {
-        if (session instanceof ServerSession) {
-            return ((ServerSession) session).getUser();
-        }
-
-        return getUser(session.getUserId(), session.getContextId());
-    }
-
     private User getUser(int userId, int contextId) throws OXException {
         UserService service = services.getService(UserService.class);
         if (service == null) {
