@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -123,7 +123,7 @@ public class PlistResult implements Result {
 
     // --------------------------------------------- E-Mail utils --------------------------------------------------------------
 
-    private TransportProvider getTransportProvider() {
+    private static TransportProvider getTransportProvider() {
         return TransportProviderRegistry.getTransportProvider("smtp");
     }
 
@@ -201,7 +201,7 @@ public class PlistResult implements Result {
         }
     }
 
-    private ThresholdFileHolder sign(ThresholdFileHolder fileHolder, Session session) throws OXException, IOException {
+    private static ThresholdFileHolder sign(ThresholdFileHolder fileHolder, Session session) throws OXException, IOException {
         ThresholdFileHolder tfh = null;
         boolean error = true;
         try {
@@ -226,7 +226,7 @@ public class PlistResult implements Result {
 
     // --------------------------------------------- SMS utils --------------------------------------------------------------
 
-    private ResultObject generateSMSResult(OnboardingRequest request, Session session) throws OXException {
+    private static ResultObject generateSMSResult(OnboardingRequest request, Session session) throws OXException {
         SMSServiceSPI smsService = Services.optService(SMSServiceSPI.class);
         if (smsService == null) {
             throw ServiceExceptionCode.absentService(SMSServiceSPI.class);
@@ -289,8 +289,7 @@ public class PlistResult implements Result {
      * @return The sanitized phone number
      * @throws OXException if the number does not start with a '+' sign
      */
-    private String sanitizeNumber(String number) throws OXException {
-
+    private static String sanitizeNumber(String number) throws OXException {
         if (!number.startsWith("+")) {
             throw OnboardingExceptionCodes.INVALID_PHONE_NUMBER.create(number);
         }
@@ -301,7 +300,7 @@ public class PlistResult implements Result {
         return "+" + number;
     }
 
-    private boolean seemsLikeDav(List<OnboardingProvider> providers) {
+    private static boolean seemsLikeDav(List<OnboardingProvider> providers) {
         if (null == providers) {
             return false;
         }
@@ -315,7 +314,7 @@ public class PlistResult implements Result {
         return false;
     }
 
-    private boolean seemsLikeMail(List<OnboardingProvider> providers) {
+    private static boolean seemsLikeMail(List<OnboardingProvider> providers) {
         if (null == providers) {
             return false;
         }
@@ -329,7 +328,7 @@ public class PlistResult implements Result {
         return false;
     }
 
-    private boolean seemsLikeEas(List<OnboardingProvider> providers) {
+    private static boolean seemsLikeEas(List<OnboardingProvider> providers) {
         if (null == providers) {
             return false;
         }
@@ -343,19 +342,20 @@ public class PlistResult implements Result {
         return false;
     }
 
-    private long getSMSRateLimit(Session session) throws OXException {
+    private static long getSMSRateLimit(Session session) throws OXException {
         ConfigViewFactory confFactory = Services.getService(ConfigViewFactory.class);
         ConfigView view = confFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<Long> property = view.property(OnboardingSMSConstants.SMS_RATE_LIMIT_PROPERTY, Long.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return -1L;
         }
 
-        return property.get().longValue();
+        Long value = property.get();
+        return value == null ? -1L : value.longValue();
     }
 
-    private int checkSMSLimit(Session session, long ratelimit, SMSBucketService smsBucketService) throws OXException {
+    private static int checkSMSLimit(Session session, long ratelimit, SMSBucketService smsBucketService) throws OXException {
         if (ratelimit > 0) {
             Long lastSMSSend = (Long) session.getParameter(OnboardingSMSConstants.SMS_LAST_SEND_TIMESTAMP);
 
@@ -371,7 +371,7 @@ public class PlistResult implements Result {
         return remainingSMS;
     }
 
-    private void setRateLimitTime(long rateLimit, Session session) {
+    private static void setRateLimitTime(long rateLimit, Session session) {
         if (rateLimit > 0) {
             session.setParameter(OnboardingSMSConstants.SMS_LAST_SEND_TIMESTAMP, Long.valueOf(System.currentTimeMillis()));
         }
