@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -159,7 +159,7 @@ public class SyncAppOnboardingProvider implements OnboardingProvider {
         }
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             throw OnboardingExceptionCodes.MISSING_PROPERTY.create(propertyName);
         }
 
