@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -364,12 +364,17 @@ public class OnboardingUtility {
         ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
         ConfigView view = viewFactory.getView(userId, contextId);
         ComposedConfigProperty<String> property = view.property("com.openexchange.client.onboarding.enabledScenarios", String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             // Nothing enabled...
             return false;
         }
 
-        String[] ids = Strings.splitByComma(Strings.asciiLowerCase(property.get()));
+        String value = property.get();
+        if (value == null) {
+            return false;
+        }
+
+        String[] ids = Strings.splitByComma(Strings.asciiLowerCase(value));
         Set<String> set = new HashSet<String>(ids.length, 0.9F);
         set.addAll(Arrays.asList(ids));
         return set.contains(Strings.asciiLowerCase(scenarioId));
@@ -437,11 +442,12 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<Boolean> property = view.property(propertyName, boolean.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
-        return property.get().booleanValue();
+        Boolean value = property.get();
+        return value == null ? defaultValue : value.booleanValue();
     }
 
     /**
@@ -484,7 +490,7 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return null;
         }
 
@@ -527,7 +533,7 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return translateDefaultValue ? StringHelper.valueOf(getLocaleFor(userId, contextId)).getString(defaultValue) : defaultValue;
         }
 
@@ -568,7 +574,7 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -606,7 +612,7 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -648,7 +654,7 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -671,7 +677,7 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return null;
         }
 
@@ -699,11 +705,15 @@ public class OnboardingUtility {
         ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return null;
         }
 
         String imageName = property.get();
+        if (null == imageName) {
+            return null;
+        }
+
         return Strings.isEmpty(imageName) ? loadIconImage(defaultImageName) : loadIconImage(imageName);
     }
 
