@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -73,8 +73,9 @@ public class OnboardingActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { UserService.class, ConfigViewFactory.class, ConfigurationService.class, MimeTypeMap.class, UserAgentParser.class, ContextService.class,
-            TranslatorFactory.class, ServerConfigService.class, CapabilityService.class, NotificationMailFactory.class, SessiondService.class };
+        return new Class<?>[] { UserService.class, ConfigViewFactory.class, ConfigurationService.class, MimeTypeMap.class,
+            UserAgentParser.class, ContextService.class, TranslatorFactory.class, ServerConfigService.class, CapabilityService.class,
+            NotificationMailFactory.class, SessiondService.class };
     }
 
     @Override
@@ -103,6 +104,7 @@ public class OnboardingActivator extends HousekeepingActivator {
             Dictionary<String, Object> properties = new Hashtable<String, Object>(1);
             properties.put(CapabilityChecker.PROPERTY_CAPABILITIES, sCapability);
             registerService(CapabilityChecker.class, new CapabilityChecker() {
+
                 @Override
                 public boolean isEnabled(String capability, Session ses) throws OXException {
                     if (sCapability.equals(capability)) {
